/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.enterprise.entry;

import java.io.IOException;
import java.time.ZonedDateTime;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.Resource;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.vorgang.VorgangNummerSupplier;
import de.ozgcloud.eingang.enterprise.entry.EntryResponse.ResponseVorgang;
import de.ozgcloud.eingang.semantik.SemantikAdapter;

@Controller
@ResponseBody
@RequestMapping("antrag")
public class EntryController {

	private static final String STARTING_STATUS = "NEU";

	@Autowired
	private EntryDataMapper mapper;

	@Autowired
	private SemantikAdapter semantikAdapter;
	@Autowired
	private VorgangNummerSupplier vorgangNummerSupplier;

	@ResponseStatus(HttpStatus.ACCEPTED)
	@PostMapping(consumes = "multipart/form-data", produces = MediaType.APPLICATION_JSON_VALUE)
	public EntryResponse receiveAntrag(@RequestPart Resource formData) throws IOException {
		var mapped = mapper.mapEntryData(formData.getInputStream());
		mapped = addVorgangNummer(mapped);

		var vorgangId = semantikAdapter.processFormData(mapped);

		return buildResponse(mapped, vorgangId);
	}

	private FormData addVorgangNummer(FormData formData) {
		var header = formData.getHeader().toBuilder().vorgangNummer(vorgangNummerSupplier.get()).build();
		return formData.toBuilder().header(header).build();
	}

	EntryResponse buildResponse(FormData formData, String vorgangId) {
		return EntryResponse.builder()
				.transactionId(formData.getHeader().getRequestId())
				.vorgang(ResponseVorgang.builder()
						.vorgangId(vorgangId)
						.vorgangNummer(formData.getHeader().getVorgangNummer())
						.status(STARTING_STATUS)
						.statusSince(ZonedDateTime.now().withNano(0))
						.build())
				.build();
	}
}
