/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.enterprise.entry;

import java.time.LocalDate;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

import lombok.Builder;
import lombok.Getter;
import lombok.ToString;
import lombok.extern.jackson.Jacksonized;

@Builder
@Getter
@Jacksonized
@ToString(onlyExplicitlyIncluded = true)
public class EntryFormDataField implements EntryFormDataItem {

	private String name;
	@ToString.Include
	private String label;

	private String stringValue;
	private Boolean booleanValue;
	private Number numberValue;
	private LocalDate dateValue;

	@Override
	public boolean isFormField() {
		return true;
	}

	public Object getValue() {
		if (StringUtils.isNotBlank(stringValue)) {
			return stringValue;
		}
		if (Objects.nonNull(booleanValue)) {
			return booleanValue;
		}
		if (Objects.nonNull(numberValue)) {
			return numberValue;
		}
		if (Objects.nonNull(dateValue)) {
			return dateValue;
		}
		return null;
	}
}
