/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formsolutions;

import java.io.File;
import java.util.Collections;
import java.util.List;
import java.util.Objects;

import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.IncomingFile;
import de.ozgcloud.eingang.common.formdata.IncomingFileGroup;

@Component
class FormSolutionsAttachmentsMapper {

	public static final String ZIP = "zip";
	public static final String FILE_NAME_ZIP_ATTACHMENT = "attachments.zip";
	public static final String ZIP_CONTENT_TYPE = "application/zip";
	public static final String FILE_GROUP_ZIP_NAME = "gezippte Anhänge";

	public List<IncomingFileGroup> mapAttachments(File zipFile) {
		if (Objects.nonNull(zipFile) && zipFile.length() > 0) {
			return Collections.singletonList(buildFileGroup(buildZipFile(zipFile)));
		}
		return Collections.emptyList();
	}

	private IncomingFileGroup buildFileGroup(IncomingFile zipFile) {
		return IncomingFileGroup.builder()
				.name(FILE_GROUP_ZIP_NAME)
				.files(List.of(zipFile))
				.build();
	}

	private IncomingFile buildZipFile(File zipFile) {
		return IncomingFile.builder()
				.file(zipFile)
				.contentType(ZIP_CONTENT_TYPE)
				.name(FILE_NAME_ZIP_ATTACHMENT)
				.build();
	}
}