/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formsolutions;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Base64;

import org.apache.commons.io.IOUtils;

import de.ozgcloud.common.binaryfile.TempFileUtils;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
class FormSolutionsFileMapperUtils {

	static InputStream decodeFile(String base64FileContent) {
		// TODO ins Dateisystem schreiben, anstatt in Memory halten
		ByteArrayInputStream base64ContentStream = new ByteArrayInputStream(base64FileContent.getBytes());
		return Base64.getDecoder().wrap(base64ContentStream);
	}

	static InputStream decode(InputStream b64InputStream) {
		return Base64.getDecoder().wrap(b64InputStream);
	}

	static File decodeBase64Content(String content) {
		var b64File = TempFileUtils.writeTmpFile(content);
		var tempFile = TempFileUtils.createTmpFile();

		try (var in = new FileInputStream(b64File); var out = new FileOutputStream(tempFile.toFile())) {
			IOUtils.copy(FormSolutionsFileMapperUtils.decode(in), out);
			out.flush();
			return tempFile.toFile();
		} catch (IOException e) {
			throw new TechnicalException("Error decoding and saving b64 file.", e);
		}
	}
}