/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formsolutions;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.File;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;
import de.ozgcloud.eingang.common.formdata.FormSolutionsTestFactory;
import de.ozgcloud.eingang.semantik.SemantikAdapter;

@DisplayName("Send form endpoint")
class SendFormEndpointTest {

	@Spy
	@InjectMocks
	private SendFormEndpoint endpoint;
	@Mock
	private SemantikAdapter semantikAdapter;
	@Mock
	private FormSolutionsRequestMapper requestMapper;

	@DisplayName("receive form")
	@Nested
	class TestReceiveForm {

		private final FormData formData = FormDataTestFactory.create();

		@Captor
		private ArgumentCaptor<File> fileCaptor;

		private static final Request REQUEST = new Request();
		static {
			REQUEST.setJSON(FormSolutionsTestFactory.SIMPLE_JSON_DATA);
		}

		@BeforeEach
		void initTest() {
			when(requestMapper.map(any())).thenReturn(formData);
		}

		@Test
		void shouldCallRequestMapper() {
			receiveForm();

			verify(requestMapper).map(fileCaptor.capture());
			assertThat(fileCaptor.getValue()).content().isEqualTo(FormSolutionsTestFactory.SIMPLE_JSON_DATA);
		}

		@Test
		void shouldCallSemantikAdapter() {
			receiveForm();

			verify(semantikAdapter).processFormData(formData);
		}

		@Test
		void shouldResponseWithOk() {
			var response = receiveForm();

			assertThat(response.getStatus()).isEqualTo("OK");
		}

		private Response receiveForm() {
			return endpoint.receiveForm(REQUEST);
		}
	}
}