/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.function.Consumer;

import org.springframework.stereotype.Component;
import org.w3c.dom.Attr;
import org.w3c.dom.Document;

@Component
public class CustomHeaderReader {

	public static final String HEADER_POSTFACH_ID = "u:saml_legacypostkorbhandle";
	public static final String HEADER_VORNAME = "u:saml_givenname";
	public static final String HEADER_NACHNAME = "u:saml_surname";
	public static final String HEADER_GEBURTSORT = "u:saml_placeofbirth";
	public static final String HEADER_GEBURTSNAME = "u:saml_birthname";
	public static final String HEADER_EMAIL = "u:saml_mail";
	public static final String HEADER_TELEFON = "u:saml_telephonenumber";
	public static final String HEADER_STRASSE = "u:saml_postaladdress";
	public static final String HEADER_PLZ = "u:saml_postalcode";
	public static final String HEADER_ORT = "u:saml_localityname";

	public Map<String, Object> getHeader(Document document) {
		var map = new HashMap<String, Object>();
		Consumer<Attr> addHeader = attr -> map.put(attr.getName(), attr.getValue());
		getAttribute(document, HEADER_POSTFACH_ID).ifPresent(addHeader);
		getAttribute(document, HEADER_VORNAME).ifPresent(addHeader);
		getAttribute(document, HEADER_NACHNAME).ifPresent(addHeader);
		getAttribute(document, HEADER_GEBURTSNAME).ifPresent(addHeader);
		getAttribute(document, HEADER_GEBURTSORT).ifPresent(addHeader);
		getAttribute(document, HEADER_EMAIL).ifPresent(addHeader);
		getAttribute(document, HEADER_TELEFON).ifPresent(addHeader);
		getAttribute(document, HEADER_STRASSE).ifPresent(addHeader);
		getAttribute(document, HEADER_PLZ).ifPresent(addHeader);
		getAttribute(document, HEADER_ORT).ifPresent(addHeader);
		return map;
	}

	Optional<Attr> getAttribute(Document document, String name) {
		return Optional.ofNullable(document.getDocumentElement().getAttributeNode(name));
	}
}