/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import java.util.List;
import java.util.UUID;

import org.springframework.stereotype.Component;

import de.ozgcloud.common.binaryfile.TempFileUtils;
import de.ozgcloud.eingang.common.formdata.IncomingFile;

@Component
class DepositRequestIncomingFileMapper {

	List<IncomingFile> mapFiles(Deposit depositData) {
		return depositData.getData().getAttachments().stream()
				.map(this::buildIncomingFile).toList();
	}

	private IncomingFile buildIncomingFile(Attachment attachment) {
		var file = TempFileUtils.writeTmpFile(attachment.content);

		return IncomingFile.builder()
				.id(UUID.randomUUID().toString())
				.vendorId(attachment.getId())
				.name(attachment.getName())
				.file(file)
				.contentType(attachment.getContentType())
				.size(attachment.getContent().length)
				.build();
	}
}
