/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.router;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.PostfachAddressIdentifier;
import de.ozgcloud.eingang.common.formdata.ServiceKonto;
import de.ozgcloud.eingang.common.formdata.StringBasedIdentifier;
import de.ozgcloud.eingang.common.formdata.ServiceKonto.PostfachAddress;
import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.vorgang.GrpcPostfachAddress;
import de.ozgcloud.vorgang.vorgang.GrpcServiceKonto;

@Component
class ServiceKontoMapper {

	@Autowired
	private GrpcObjectMapper grpcObjectMapper;

	public GrpcServiceKonto toServiceKonto(ServiceKonto serviceKonto) {
		return GrpcServiceKonto.newBuilder()
				.setType(serviceKonto.getType())
				.addAllPostfachAddresses(getPostfachAddresses(serviceKonto))
				.build();
	}

	private List<GrpcPostfachAddress> getPostfachAddresses(ServiceKonto serviceKonto) {
		return serviceKonto.getPostfachAddresses().stream().map(this::fromPostfachAddress).toList();
	}

	private GrpcPostfachAddress fromPostfachAddress(PostfachAddress postfachAddress) {
		return GrpcPostfachAddress.newBuilder()
				.setVersion(postfachAddress.getVersion())
				.setType(postfachAddress.getType())
				.setIdentifier(mapFromIdentifier(postfachAddress.getIdentifier()))
				.build();
	}

	GrpcObject mapFromIdentifier(PostfachAddressIdentifier identifier) {
		return grpcObjectMapper.fromMap(Map.of(StringBasedIdentifier.POSTFACH_ID_FIELD, getStringBasedValue(identifier)));
	}

	private String getStringBasedValue(PostfachAddressIdentifier identifier) {
		return ((StringBasedIdentifier) identifier).getPostfachId();
	}
}