/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.afm;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Optional;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.semantik.enginebased.EngineBasedMapper;

interface AfmEngineBasedMapper extends EngineBasedMapper {

	 String KOP_CONTROLDATA_NODENAME = "_kopControlData";
	 String CONTROLDATA_METADATA_PROPERTYNAME = "metaData";

	default FormData addControlNode(FormData formData, String nodeName) {
		var editableFormMap = new LinkedHashMap<>(formData.getFormData());

		return Optional.ofNullable(getFormNode(formData, nodeName))
				.map(LinkedHashMap::new)
				.map(empfStelleMap -> {
					empfStelleMap.put(KOP_CONTROLDATA_NODENAME, buildControlDataMap());
					editableFormMap.put(nodeName, empfStelleMap);
					return editableFormMap;
				})
				.map(formDataMap -> formData.toBuilder().formData(Collections.unmodifiableMap(formDataMap)).build())
				.orElse(formData);

	}

	@SuppressWarnings("unchecked")
	default Map<String, Object> getFormNode(FormData formData, String nodeName) {
		return (Map<String, Object>) formData.getFormData().get(nodeName);
	}

	default Map<String, Object> buildControlDataMap() {
		Map<String, Object> controlMap = new LinkedHashMap<>();
		controlMap.put(CONTROLDATA_METADATA_PROPERTYNAME, "true");
		return controlMap;
	}
}
