/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.formcycle;

import java.util.Map;
import java.util.Optional;

import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.Antragsteller;
import de.ozgcloud.eingang.common.formdata.FormData;

@Component
public class FormcycleAntragstellerMapper implements FormcycleEngineBasedMapper {

	static final String KEY_ANTRAGSTELLER = "fsBKAllDaten";
	static final String KEY_ANREDE = "tfAntragstellerAnrede";
	static final String KEY_VORNAME = "tfAntragstellerVorname";
	static final String KEY_NACHNAME = "tfAntragstellerName";
	static final String KEY_GEBURTSNAME = "tfAntragstellerGeburtsname";
	static final String KEY_GEBURTSDATUM = "tfAntragstellerGeburtsdatum";
	static final String KEY_GEBURTSORT = "tfAntragstellerGeburtsort";
	static final String KEY_EMAIL = "tfAntragstellerEmail";
	static final String KEY_TELEFON = "tfAntragstellerTelefon";
	static final String KEY_ADDRESS = "tfAntragstellerAdresse";
	static final String KEY_PLZ = "tfAntragstellerPLZ";
	static final String KEY_ORT = "tfAntragstellerOrt";

	@Override
	public FormData parseFormData(final FormData formData) {
		return getAntragstellerData(formData.getFormData())
				.map(this::buildAntragsteller)
				.map(antragsteller -> formData.toBuilder().antragsteller(antragsteller).build())
				.orElse(formData);
	}

	@SuppressWarnings("unchecked")
	Optional<Map<String, Object>> getAntragstellerData(Map<String, Object> formDataMap) {
		var antragstellerData = (Map<String, Object>) MapUtils.getMap(formDataMap, KEY_ANTRAGSTELLER);
		return Optional.ofNullable(antragstellerData).map(map -> (Map<String, Object>) map.get("value"));
	}

	Antragsteller buildAntragsteller(Map<String, Object> antragstellerData) {
		return Antragsteller.builder()
				.anrede(getValue(antragstellerData, KEY_ANREDE))
				.vorname(getValue(antragstellerData, KEY_VORNAME))
				.nachname(getValue(antragstellerData, KEY_NACHNAME))
				.geburtsname(getValue(antragstellerData, KEY_GEBURTSNAME))
				.geburtsdatum(getValue(antragstellerData, KEY_GEBURTSDATUM))
				.geburtsort(getValue(antragstellerData, KEY_GEBURTSORT))
				.email(getValue(antragstellerData, KEY_EMAIL))
				.telefon(getValue(antragstellerData, KEY_TELEFON))
				.strasse(getValue(antragstellerData, KEY_ADDRESS))
				.plz(getValue(antragstellerData, KEY_PLZ))
				.ort(getValue(antragstellerData, KEY_ORT))
				.build();
	}

	String getValue(Map<String, Object> formDataMap, String key) {
		return Optional.ofNullable(MapUtils.getMap(formDataMap, key)).map(map -> map.get("value")).map(String::valueOf).orElse(StringUtils.EMPTY);
	}
}
