/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.xta;

import java.util.Collections;
import java.util.List;
import java.util.function.Predicate;

import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.IncomingFile;
import de.ozgcloud.eingang.semantik.common.ZipAttachmentReader;
import lombok.extern.log4j.Log4j2;

@Component
@Log4j2
public class XtaZipRepresentationsMapper implements XtaEngineBasedMapper {

	public static final String ZIP_CONTENT_TYPE = "application/zip";

	static final Predicate<IncomingFile> IS_ZIP_FILE = contentType -> ZIP_CONTENT_TYPE.equals(contentType.getContentType());

	@Override
	public FormData parseFormData(FormData srcFormData) {

		List<IncomingFile> extractedFiles = srcFormData.getRepresentations().stream()
				.filter(IS_ZIP_FILE)
				.map(this::extractZip)
				.flatMap(List::stream)
				.toList();

		return srcFormData
				.toBuilder()
				.representations(extractedFiles)
				.numberOfRepresentations(srcFormData.getNumberOfRepresentations() + extractedFiles.size()).build();
	}

	List<IncomingFile> extractZip(IncomingFile zipFile) {
		try {
			return ZipAttachmentReader.from(zipFile.getContentStream(), zipFile.getName()).readContent();
		} catch (RuntimeException e) {
			LOG.error("Cannot read source ZIP. Not extracting file", e);
			return Collections.emptyList();
		}
	}
}
