/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.afm;

import static org.assertj.core.api.Assertions.*;

import java.util.List;
import java.util.Map;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;
import de.ozgcloud.eingang.common.formdata.IncomingFileGroup;
import de.ozgcloud.eingang.common.formdata.IncomingFileGroupTestFactory;
import de.ozgcloud.eingang.common.formdata.IncomingFileTestFactory;
import de.ozgcloud.eingang.semantik.enginebased.FilesMapperHelper;
import de.ozgcloud.eingang.semantik.enginebased.afm.AfmAttachedFilesMapper;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Spy;

class AfmAttachedFilesMapperTest {

	@Spy
	@InjectMocks
	private AfmAttachedFilesMapper mapper;

	private IncomingFileGroup attachmentWithMultipleFiles = IncomingFileGroupTestFactory.createBuilder()
			.name("anotherAttachment")
			.clearFiles()
			.files(List.of(IncomingFileTestFactory.create(), IncomingFileTestFactory.create()))
			.build();

	private FormData formData = FormDataTestFactory.createBuilder()
			.clearAttachments()
			.formData(Map.of(FilesMapperHelper.FIELD_NAME_MAPPED_FILES,
					Map.of(FilesMapperHelper.ATTACHMENTS, List.of(IncomingFileGroupTestFactory.create(), attachmentWithMultipleFiles))))
			.build();

	@Nested
	class TestParseFormData {

		@Test
		void shouldMapAttachments() {
			var parsedFormData = parseFormData();

			assertThat(parsedFormData.getAttachments()).hasSize(2);
			assertThat(parsedFormData.getAttachments().get(0).getFiles()).hasSize(1);
			assertThat(parsedFormData.getAttachments().get(1).getFiles()).hasSize(2);
		}

		@Test
		void shouldSetNumberOfAttachments() {
			var parsedFormData = parseFormData();

			assertThat(parsedFormData.getNumberOfAttachments()).isEqualTo(3);
		}

		@Test
		void shouldMapRepresentations() {
			var parsedFormData = parseFormData();

			assertThat(parsedFormData.getRepresentations()).hasSize(1);
		}

		@Test
		void shouldSetNumberOfRepresentations() {
			var parsedFormData = parseFormData();

			assertThat(parsedFormData.getNumberOfRepresentations()).isEqualTo(1);
		}

		@Test
		void shouldRemoveFilesFromMap() {
			var parsedFormData = parseFormData();

			assertThat(parsedFormData.getFormData().get(FilesMapperHelper.FIELD_NAME_MAPPED_FILES)).isNull();
		}

		private FormData parseFormData() {
			return mapper.parseFormData(formData);
		}
	}
}