# Intelliform Adapter

Adapter zum empfangen von Formulardaten von einem IntellForm basierten Formularserver, zum Beispiel iAFM (integriertes Antrags- und Formularmanagement).

## Routingkonfiguration

### Vorgang-Manager Instanzen

Für alle Vorgang-Manager-Instanzen, die von dem Adapter erreichbar sein sollen, muss in das _Environment_ ein Eintrag mit dem GRPC-Service ergänzt werden:

```yaml
grpc.client.vorgang-manager-*vorgang-manager-name*.address:*url und port*
grpc.client.vorgang-manager-*vorgang-manager-name*.negotiationType: PLAINTEXT
```

### Fallback Strategy

Die Fallback Stratey steuert wie mit Eingängen umgegangen werden soll, für die keine passende Vorgang-Manager-Instanze gefunden werden konnte.

Folgende Optionen stehen zur Verfügung:

- **DENY** der Antrag wird mit einer Fehlermeldung abgelehnt. Dies funktioniert nur, solange die Abarbeitung synchron erfolgt.

- **FUNDSTELLE** der Antrag wird an eine zentrale Fundstelle weitergeleitet. Dafür muss der Name der Vorgang-Manager-Instanze, die als Fundstelle fungiert, eingetragen werden.

### Routing Strategy

Die Routing Strategy steuert wie das Routing konfiguriert wird und wieviele Vorgang-Manager-Instanzen berücksichtigt werden können.

Folgende Optionen stehen zur Verfügung:

- **MULTI** es kann an beliebig viele Vorgang-Manager-Instanzen geroutet werden. Dafür muss in der Environment ein Mapping der Organisationseinheit-Id auf den Namen einer Vorgang-Manager-Instanz konfiguriert werden.

```yaml
ozgcloud.adapter.organisationseinheiten.*id*: *vorgang-manager-name*
```

- **SINGLE** es wird immer nur an eine Vorgang-Manager-Instanze geroutet, der Name der Instanz ist im Feld 'Vorgang-Manager Name' anzugeben.

### Beispielkonfiguration

```yaml
env:
  springProfiles: "oc, dev"
  grpc:
    - name: grpc_client_vorgang-manager-test_address
      value: "vorgang-manager.test:9090"
    - name: grpc_client_vorgang-manager-test_negotiationType
      value: PLAINTEXT
    - name: ozgcloud.adapter.organisationseinheiten.1357913579
      value: test
image:
  tag: snapshot-latest
imageCredentials:
  email: webmaster@ozg-sh.de
  password: 
  registry: docker.ozg-sh.de
  username: ozgcloud
ingress:
  host: kiel-afm.dev.by.ozg-cloud.de
replicaCount: 2
resources:
  limits:
    cpu: 1
    memory: 1200Mi
  requests:
    cpu: 100m
    memory: 250Mi
global:
  cattle:
    clusterId: c-8g78g
    clusterName: ozg-dev
    systemDefaultRegistry: ""
  systemDefaultRegistry: ""
routing:
  fallbackStrategy: FUNDSTELLE
  fundstelleVorgangManagerName: kiel
  routingStrategy: MULTI
  targetVorgangManagerName: kiel
```

### Benutzung beliebiger environment Werte

In jedem der Projekte kann man beliebige weitere environments setzen. Dazu muss man in der jeweiligen values.yaml unter env.customList ein name value Paar setzen:

```yaml
env:
  customList:
    - name: Dinge
      value: true
    - name: ...
      value: ...
```
