/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import java.math.BigInteger;
import java.util.Optional;
import java.util.stream.Stream;

import jakarta.xml.bind.JAXBElement;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;

import eu.osci.ws._2008._05.transport.MsgStatusListType;
import eu.osci.ws._2014._10.transport.MessageMetaData;

@Mapper
interface XtaMessageMetaDataMapper {

	@Mapping(target = "origin", source = "deliveryAttributes.origin")
	@Mapping(target = "delivery", source = "deliveryAttributes.delivery")
	@Mapping(target = "messageId", source = "msgIdentification.messageID.value")
	@Mapping(target = "messageType", source = "qualifier.messageType.code")
	XtaMessageMetaData fromSoap(MessageMetaData metaData);

	default XtaMessageId fromString(String id) {
		return XtaMessageId.from(id);
	}

	@Mapping(target = "moreMessagesAvailable", source = ".", qualifiedByName = "moreMessagesAvailable")
	XtaMessageMetaDatasAndHeader msgStatusListFromSoap(MsgStatusListTypeAndHeaderResponse statusList);

	@Named("moreMessagesAvailable")
	default boolean moreMessagesAvailable(MsgStatusListTypeAndHeaderResponse statusList) {
		if (statusList.isNoMessageAvailable()) {
			return false;
		}
		return Optional.ofNullable(statusList.getMessageItemsPending())
				.filter(messagesPending -> !BigInteger.ZERO.equals(messagesPending))
				.isPresent();
	}

	default Stream<XtaMessageMetaData> map(JAXBElement<MsgStatusListType> msgStatusListResponse) {
		return msgStatusListResponse.getValue().getMessageMetaData().stream().map(this::fromSoap);
	}
}
