/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;

import java.math.BigInteger;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

class XtaMessageMetaDataMapperTest {

	@Spy
	private final XtaMessageMetaDataMapper mapper = Mappers.getMapper(XtaMessageMetaDataMapper.class);

	@Nested
	class TestMoreMessagesAvailable {

		@Test
		void shouldReturnFalseOnNoMessagesAvailable() {

			var response = mapper.moreMessagesAvailable(buildWithNoMessageAvailable());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithNoMessageAvailable() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().noMessageAvailable(true).build();
		}

		@Test
		void shouldReturnFalseOnPendingMessagesNull() {

			var response = mapper.moreMessagesAvailable(buildPendingMessagesNull());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildPendingMessagesNull() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(null).build();
		}

		@Test
		void shouldReturnFalseOnNoMessagesPending() {

			var response = mapper.moreMessagesAvailable(buildWithoutPendingMessages());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithoutPendingMessages() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(null).build();
		}

		@Test
		void shouldReturnTrueOnMessagesPending() {

			var response = mapper.moreMessagesAvailable(buildWithPendingMessages());

			assertThat(response).isTrue();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithPendingMessages() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(BigInteger.ONE).build();
		}
	}
}
