/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.boot.webservices.client.WebServiceTemplateBuilder;

class XtaRemoteServiceTest {

	@Spy
	@InjectMocks
	private XtaRemoteService service;

	@Mock
	private WebServiceTemplateBuilder templateBuilder;
	@Mock
	private XtaMessageMetaDataMapper mapper;
	@Spy
	private XtaProperties properties = XtaPropertiesTestFactory.create();

	@Nested
	class TestGetMessagesMetadata {

		@BeforeEach
		void init() {
			doReturn(MsgStatusListTypeAndHeaderResponseTestFactory.create()).when(service).getStatusList();
			when(mapper.msgStatusListFromSoap(any(MsgStatusListTypeAndHeaderResponse.class)))
					.thenReturn(XtaMessageMetaDatasAndHeaderTestFactory.create());
		}

		@Test
		void shouldCallGetStatusList() {
			service.getMessagesMetadata().getMessages().toList();

			verify(service).getStatusList();
		}

		@Test
		void shouldCallMapper() {
			service.getMessagesMetadata();

			verify(mapper).msgStatusListFromSoap(notNull());
		}

		@Test
		void shouldReturnMessageId() {
			var metaData = service.getMessagesMetadata().getMessages().toList();

			assertThat(metaData).hasSize(1).first().usingRecursiveComparison().isEqualTo(XtaMessageMetaDataTestFactory.create());
		}
	}

	@Nested
	class TestGetNextMessagesMetadata {

		@BeforeEach
		void init() {
			doReturn(MsgStatusListTypeAndHeaderResponseTestFactory.create()).when(service).getStatusList();
			when(mapper.msgStatusListFromSoap(any(MsgStatusListTypeAndHeaderResponse.class)))
					.thenReturn(XtaMessageMetaDatasAndHeaderTestFactory.create());
		}

		@Test
		void shouldCallGetNextStatusList() {
			service.getMessagesMetadata().getMessages().toList();

			verify(service).getStatusList();
		}

		@Test
		void shouldCallMapper() {
			service.getMessagesMetadata();

			verify(mapper).msgStatusListFromSoap(notNull());
		}

		@Test
		void shouldReturnMessageId() {
			var metaData = service.getMessagesMetadata().getMessages().toList();

			assertThat(metaData).hasSize(1).first().usingRecursiveComparison().isEqualTo(XtaMessageMetaDataTestFactory.create());
		}
	}

	@Nested
	class TestGetMessage {

		private XtaFile file = XtaFileTestFactory.create();

		@BeforeEach
		void init() {
			doReturn(file).when(service).getMessage(anyString());
		}

		@Test
		void shouldCallGetMessage() {
			service.getMessage(XtaMessageTestFactory.MESSAGE_ID);

			verify(service).getMessage(XtaMessageTestFactory.MESSAGE_ID.toString());
		}

		@Test
		void shouldReturnMessageWithoutMetaData() {
			var message = service.getMessage(XtaMessageTestFactory.MESSAGE_ID);

			assertThat(message.getMetaData()).isNull();
		}

		@Test
		void hosuldReturnMessageWithFile() {
			var message = service.getMessage(XtaMessageTestFactory.MESSAGE_ID);

			assertThat(message.getMessageFiles()).hasSize(1).contains(file);
		}
	}
}